==> dkd-0.11.1.tar.gz: dkd-0.11.1/dkd/envelope_impl.py <==
# -*- coding: utf-8 -*-
#
#   Dao-Ke-Dao: Universal Message Module
#
#                                Written in 2019 by Moky <albert.moky@gmail.com>
#
# ==============================================================================
# MIT License
#
# Copyright (c) 2019 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================

import time as time_lib
from typing import Optional, Union

from mkm.crypto import Dictionary
from mkm import ID, ANYONE

from .types import ContentType
from .envelope import Envelope, EnvelopeFactory


"""
    Message Envelope
    ~~~~~~~~~~~~~~~~

    Implementations for Envelope
"""


class MessageEnvelope(Dictionary, Envelope):

    def __init__(self, envelope: Optional[dict] = None,
                 sender: Optional[ID] = None, receiver: Optional[ID] = None, time: Optional[int] = 0):
        if envelope is None:
            assert sender is not None, 'sender should not be empty'
            if receiver is None:
                receiver = ANYONE
            if time == 0:
                time = int(time_lib.time())
            envelope = {
                'sender': str(sender),
                'receiver': str(receiver),
                'time': time,
            }
        # initialize with envelope info
        super().__init__(dictionary=envelope)
        # lazy load
        self.__sender = sender
        self.__receiver = receiver
        self.__time = time
        self.__group = None
        self.__type = 0

    @property  # Override
    def sender(self) -> ID:
        if self.__sender is None:
            identifier = self.get('sender')
            self.__sender = ID.parse(identifier=identifier)
        return self.__sender

    @property  # Override
    def receiver(self) -> ID:
        if self.__receiver is None:
            identifier = self.get('receiver')
            if identifier is None:
                self.__receiver = ANYONE
            else:
                self.__receiver = ID.parse(identifier=identifier)
        return self.__receiver

    @property  # Override
    def time(self) -> int:
        if self.__time == 0:
            timestamp = self.get('time')
            if timestamp is not None:
                self.__time = int(timestamp)
        return self.__time

    @property  # Override
    def group(self) -> Optional[ID]:
        if self.__group is None:
            identifier = self.get('group')
            if identifier is not None:
                self.__group = ID.parse(identifier=identifier)
        return self.__group

    @group.setter  # Override
    def group(self, value: ID):
        if value is None:
            self.pop('group', None)
        else:
            self['group'] = str(value)
        self.__group = value

    @property  # Override
    def type(self) -> Optional[int]:
        if self.__type == 0:
            value = self.get('type')
            if value is not None:
                self.__type = int(value)
        return self.__type

    @type.setter  # Override
    def type(self, value: Union[ContentType, int]):
        if isinstance(value, ContentType):
            value = value.value
        if value == 0:
            self.pop('type', None)
        else:
            self['type'] = value
        self.__type = value


class MessageEnvelopeFactory(EnvelopeFactory):

    # Override
    def create_envelope(self, sender: ID, receiver: ID, time: int) -> Envelope:
        return MessageEnvelope(sender=sender, receiver=receiver, time=time)

    # Override
    def parse_envelope(self, envelope: dict) -> Optional[Envelope]:
        # env.sender should not empty
        if envelope.get('sender') is not None:
            return MessageEnvelope(envelope=envelope)


# register Envelope factory
Envelope.register(factory=MessageEnvelopeFactory())

==> dkd-0.11.5.tar.gz: dkd-0.11.5/dkd/envelope_impl.py <==
# -*- coding: utf-8 -*-
#
#   Dao-Ke-Dao: Universal Message Module
#
#                                Written in 2019 by Moky <albert.moky@gmail.com>
#
# ==============================================================================
# MIT License
#
# Copyright (c) 2019 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================

import time as time_lib
from typing import Optional, Union

from mkm.wrappers import Dictionary
from mkm import ID, ANYONE

from .types import ContentType
from .envelope import Envelope, EnvelopeFactory


"""
    Message Envelope
    ~~~~~~~~~~~~~~~~

    Implementations for Envelope
"""


class MessageEnvelope(Dictionary, Envelope):

    def __init__(self, envelope: Optional[dict] = None,
                 sender: Optional[ID] = None, receiver: Optional[ID] = None, time: Optional[float] = 0):
        if envelope is None:
            assert sender is not None, 'sender should not be empty'
            if receiver is None:
                receiver = ANYONE
            if time == 0:
                time = time_lib.time()
            envelope = {
                'sender': str(sender),
                'receiver': str(receiver),
                'time': time,
            }
        # initialize with envelope info
        super().__init__(dictionary=envelope)
        # lazy load
        self.__sender = sender
        self.__receiver = receiver
        self.__time = time
        self.__group = None
        self.__type = 0

    @property  # Override
    def sender(self) -> ID:
        if self.__sender is None:
            identifier = self.get('sender')
            self.__sender = ID.parse(identifier=identifier)
        return self.__sender

    @property  # Override
    def receiver(self) -> ID:
        if self.__receiver is None:
            identifier = self.get('receiver')
            if identifier is None:
                self.__receiver = ANYONE
            else:
                self.__receiver = ID.parse(identifier=identifier)
        return self.__receiver

    @property  # Override
    def time(self) -> float:
        if self.__time == 0:
            timestamp = self.get('time')
            if timestamp is not None:
                self.__time = float(timestamp)
        return self.__time

    @property  # Override
    def group(self) -> Optional[ID]:
        if self.__group is None:
            identifier = self.get('group')
            self.__group = ID.parse(identifier=identifier)
        return self.__group

    @group.setter  # Override
    def group(self, value: ID):
        if value is None:
            self.pop('group', None)
        else:
            self['group'] = str(value)
        self.__group = value

    @property  # Override
    def type(self) -> Optional[int]:
        if self.__type == 0:
            value = self.get('type')
            if value is not None:
                self.__type = int(value)
        return self.__type

    @type.setter  # Override
    def type(self, value: Union[int, ContentType]):
        if isinstance(value, ContentType):
            value = value.value
        if value == 0:
            self.pop('type', None)
        else:
            self['type'] = value
        self.__type = value


class MessageEnvelopeFactory(EnvelopeFactory):

    # Override
    def create_envelope(self, sender: ID, receiver: ID, time: float) -> Envelope:
        return MessageEnvelope(sender=sender, receiver=receiver, time=time)

    # Override
    def parse_envelope(self, envelope: dict) -> Optional[Envelope]:
        # env.sender should not empty
        if envelope.get('sender') is not None:
            return MessageEnvelope(envelope=envelope)


# register Envelope factory
Envelope.register(factory=MessageEnvelopeFactory())
